==> xcsoar-6.8.3.tar.xz: xcsoar-6.8.3/src/Widget/ListWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LIST_WIDGET_HPP
#define XCSOAR_LIST_WIDGET_HPP

#include "WindowWidget.hpp"
#include "Form/List.hpp"

class Window;

/**
 * A wrapper that turns a #ListControl into a #Widget.  Call
 * CreateList() in your implementation to create and set the
 * #ListControl.  It is not deleted automatically; call
 * WindowWidget::DeleteWindow() to do that at your choice.
 */
class ListWidget
  : public WindowWidget, protected ListItemRenderer,
    protected ListCursorHandler {
protected:
  const ListControl &GetList() const {
    return (const ListControl &)GetWindow();
  }

  ListControl &GetList() {
    return (ListControl &)GetWindow();
  }

  ListControl &CreateList(ContainerWindow &parent, const DialogLook &look,
                          const PixelRect &rc, UPixelScalar row_height);

public:
  PixelSize GetMinimumSize() const override;
  PixelSize GetMaximumSize() const override;

  bool SetFocus() override {
    GetList().SetFocus();
    return true;
  }
};

#endif

==> xcsoar-7.13.tar.xz: xcsoar-7.13/src/Widget/ListWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LIST_WIDGET_HPP
#define XCSOAR_LIST_WIDGET_HPP

#include "WindowWidget.hpp"
#include "Form/List.hpp"

class Window;

/**
 * A wrapper that turns a #ListControl into a #Widget.  Call
 * CreateList() in your implementation to create and set the
 * #ListControl.  It is not deleted automatically; call
 * WindowWidget::DeleteWindow() to do that at your choice.
 */
class ListWidget
  : public WindowWidget, protected ListItemRenderer,
    protected ListCursorHandler {
protected:
  const ListControl &GetList() const noexcept {
    return (const ListControl &)GetWindow();
  }

  ListControl &GetList() noexcept {
    return (ListControl &)GetWindow();
  }

  ListControl &CreateList(ContainerWindow &parent, const DialogLook &look,
                          const PixelRect &rc, unsigned row_height) noexcept;

public:
  PixelSize GetMinimumSize() const noexcept override;
  PixelSize GetMaximumSize() const noexcept override;

  bool SetFocus() noexcept override {
    GetList().SetFocus();
    return true;
  }
};

#endif
